/**
 * Compiler options required to avoid critical functionality issues
 */
export declare const CORE_COMPILER_OPTIONS: {
    noEmit: true;
    noUnusedLocals: true;
    noUnusedParameters: true;
};
//# sourceMappingURL=compilerOptions.d.ts.map