"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CORE_COMPILER_OPTIONS = void 0;
/**
 * Compiler options required to avoid critical functionality issues
 */
exports.CORE_COMPILER_OPTIONS = {
    // Required to avoid parse from causing emit to occur
    noEmit: true,
    // Flags required to make no-unused-vars work
    noUnusedLocals: true,
    noUnusedParameters: true,
};
